@@ -27,6 +27,8 @@ my $parent;
 my $config      = 't/_DBDIR/test-config.ini';
 my $dbconfig    = 't/_DBDIR/databases.ini';
 
+my $config_dir  = 't/_DBDIR';
+
 $ENV{TZ} = 'GMT';
 
 #----------------------------------------------------------------------------
@@ -74,6 +76,11 @@ sub create_config {
     return $file2;
 }
 
+sub has_environment {
+    return 0    unless(-f $config);
+    return 1;
+}
+
 sub _cleanDir {
   my $dir = shift;
   if( -d $dir ){ rmtree($dir) or return; }
